pyprocar.io.bxsf.BxsfParser — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# pyprocar.io.bxsf.BxsfParser

class pyprocar.io.bxsf.BxsfParser(infiles=['in.bxsf'])

  The class is used to parse the information inside bxsf files

  Parameters:

    infiles (list, optional) – This is a list of .bxsf filenames to parse through. It is a list because in some codes there can be multiple .bsxf files representing spin-up and spin-sown bands ,by default [“in.bxsf”]

  Methods

  `BxsfParser.__init__`([infiles]) |
  `BxsfParser.parse_bxsf`(infiles) | A Helper method to parse bxsf files